MultihostEngine
===============

How to deploy multihost OpenStack

MultihostEngine's configuration contains two sections: controller and nodes.

Controller section
------------------

This section is full configuration of a deployment. Returned endpoints is
endpoints of the whole cloud.

Nodes section
-------------

This section is a list of full configurations of a compute nodes. Returned
endpoints are silently ignored.
